const ethers = require('ethers');

const { getContractAddressByNetworkName } = require('./contract-config');
const DAOArtifact = require('../contractArtifacts/DAO.json');

const network = process.env.ETH_NETWORK;

console.log('network:', network);

const getProvider = () => {
  switch (network) {
    case 'localhost':
      return ethers.getDefaultProvider('http://localhost:8545');
    case 'sepolia':
      return new ethers.InfuraProvider(
        network,
        process.env.INFURA_API_KEY,
      );
    default:
      throw new Error('Unknown network');
  }
};

const wallet = new ethers.Wallet(process.env.ETH_PRIVATE_KEY, getProvider());

const getContract = (name) => new ethers.Contract(
  getContractAddressByNetworkName(process.env.ETH_NETWORK, name),
  DAOArtifact.abi,
  wallet,
);

module.exports = {
  dao: getContract('DAO'),
};
